@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 __author__ = "Chris Griffith"
-__version__ = "5.1.1"
+__version__ = "5.2.0"
 
 from box.box import Box
 from box.box_list import BoxList
@@ -10,3 +10,13 @@ from box.config_box import ConfigBox
 from box.exceptions import BoxError, BoxKeyError
 from box.from_file import box_from_file
 from box.shorthand_box import SBox
+
+__all__ = [
+    "Box",
+    "BoxList",
+    "ConfigBox",
+    "BoxError",
+    "BoxKeyError",
+    "box_from_file",
+    "SBox",
+]
