@@ -328,17 +328,17 @@ class TestBox:
         assert bx.Key_2 == Box()
 
     def test_bad_from_json(self):
-        with pytest.raises(BoxError) as err:
+        with pytest.raises(BoxError):
             Box.from_json()
 
-        with pytest.raises(BoxError) as err2:
+        with pytest.raises(BoxError):
             Box.from_json(json_string="[1]")
 
     def test_bad_from_yaml(self):
-        with pytest.raises(BoxError) as err:
+        with pytest.raises(BoxError):
             Box.from_yaml()
 
-        with pytest.raises(BoxError) as err2:
+        with pytest.raises(BoxError):
             Box.from_yaml("lol")
 
     def test_conversion_box(self):
@@ -370,6 +370,21 @@ class TestBox:
         with pytest.raises(TypeError):
             hash(bx)
 
+        with pytest.raises(BoxError):
+            bx.clear()
+
+        with pytest.raises(BoxError):
+            bx.pop("alist")
+
+        with pytest.raises(BoxError):
+            bx.popitem()
+
+        with pytest.raises(BoxError):
+            bx.popitem()
+
+        with pytest.raises(BoxError):
+            bx.update({"another_list": []})
+
         bx2 = Box(test_dict)
         with pytest.raises(TypeError):
             hash(bx2)
@@ -567,7 +582,7 @@ class TestBox:
         assert a[1].b == 3
 
     def test_duplicate_errors(self):
-        with pytest.raises(BoxError) as err:
+        with pytest.raises(BoxError):
             Box({"?a": 1, "!a": 3}, box_duplicates="error")
 
         Box({"?a": 1, "!a": 3}, box_duplicates="ignore")
@@ -755,7 +770,9 @@ class TestBox:
 
     def test_inheritance(self):
         data = {
-            "users": [{"users": [{"name": "B"}]},],
+            "users": [
+                {"users": [{"name": "B"}]},
+            ],
         }
 
         class UsersBoxList(BoxList):
